==> brewer-0.3.9.tgz: package/lib/source.js <==
(function() {
  var Source, debug, info, util, _, _ref,
    __hasProp = {}.hasOwnProperty,
    __slice = [].slice,
    __indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };

  util = require('./util');

  _ref = require('./command'), debug = _ref.debug, info = _ref.info;

  _ = require('underscore');

  Source = (function() {

    Source.types = function() {
      var type, _results;
      _results = [];
      for (type in this) {
        if (!__hasProp.call(this, type)) continue;
        if (type !== 'types' && type !== 'extend' && type !== 'create') {
          _results.push(type);
        }
      }
      return _results;
    };

    Source.extend = function() {
      var alias, sources, src, _i, _len, _results;
      sources = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      _results = [];
      for (_i = 0, _len = sources.length; _i < _len; _i++) {
        src = sources[_i];
        this[src.type] = src;
        _results.push((function() {
          var _j, _len1, _ref1, _ref2, _results1;
          _ref2 = (_ref1 = src.aliases) != null ? _ref1 : [];
          _results1 = [];
          for (_j = 0, _len1 = _ref2.length; _j < _len1; _j++) {
            alias = _ref2[_j];
            _results1.push(this[alias] = src);
          }
          return _results1;
        }).call(this));
      }
      return _results;
    };

    Source.create = function(options, pkg) {
      var typ;
      if ((typ = this[options.type]) == null) {
        throw "Source type " + options.type + " not known";
      }
      return new typ(options, pkg);
    };

    function Source(options, _package) {
      var join, _ref1;
      this.options = options;
      this["package"] = _package;
      join = require('path').join;
      (require('underscore')).defaults(this.options, {
        watch: true
      });
      _ref1 = this.options, this.path = _ref1.path, this.requirements = _ref1.requirements, this.output = _ref1.output, this.prefix = _ref1.prefix;
      this.output || (this.output = join(".cache", this.path));
      this.shouldWatch = this.options.watch;
      util.makedirs(this.path);
    }

    Source.prototype.requiredModules = function() {
      return [];
    };

    Source.prototype.createFile = function(fpath) {
      var ctor, file, fullpath, imports, join, _ref1, _ref2;
      join = require('path').join;
      ctor = this.constructor;
      fullpath = join(this.path, fpath);
      fpath = util.changeext(fpath, '');
      if (this.prefix != null) {
        fpath = join(this.prefix, fpath);
      }
      file = this["package"].file(fpath, ctor.type, fullpath, this);
      file.register();
      if (this.requirements != null) {
        imports = (_ref1 = this.requirements[file.relpath]) != null ? _ref1 : [];
        imports = imports.concat((_ref2 = this.requirements.all) != null ? _ref2 : []);
        file.setImportedPaths(imports);
      }
      return file;
    };

    Source.prototype.test = function(path) {
      var ext;
      ext = this.constructor.ext;
      if (_.isArray(ext)) {
        return _.any(ext, function(_ext) {
          return util.hasext(path, _ext);
        });
      } else {
        return util.hasext(path, ext);
      }
    };

    Source.prototype.list = function(cb, end) {
      var filelist, join, rpath, walk, walker,
        _this = this;
      walk = require('walker');
      join = require('path').join;
      filelist = [];
      walker = new walk((rpath = join(this.path, '')), {
        followLinks: true
      });
      walker.on('file', function(root, stat) {
        var fpath;
        fpath = join(root.slice(rpath.length + 1), stat.name);
        if (!_this.test(fpath)) {
          return;
        }
        return cb(fpath);
      });
      if (end != null) {
        return walker.on('end', end);
      }
    };

    Source.prototype.files = function(cb, list) {
      var each,
        _this = this;
      if (this.filelist != null) {
        if (cb != null) {
          (require('underscore')).each(this.filelist, cb);
        }
        if (list != null) {
          return list(this.filelist);
        }
      } else {
        this.filelist = [];
        each = function(fpath) {
          var file;
          file = _this.createFile(fpath);
          if (cb != null) {
            cb(file);
          }
          return _this.filelist.push(file);
        };
        return this.list(each, function() {
          if (list != null) {
            return list(_this.filelist);
          }
        });
      }
    };

    Source.prototype.watch = function(reset) {
      var filelist,
        _this = this;
      if (!this.shouldWatch) {
        return;
      }
      filelist = null;
      require('./index').watchers.incr();
      return this.watcher = (require('fs')).watch(this.path, function(event) {
        var f;
        if (_this.filelist == null) {
          return;
        }
        if (filelist == null) {
          filelist = (function() {
            var _i, _len, _ref1, _results;
            _ref1 = this.filelist;
            _results = [];
            for (_i = 0, _len = _ref1.length; _i < _len; _i++) {
              f = _ref1[_i];
              _results.push(f.relpath);
            }
            return _results;
          }).call(_this);
        }
        return _this.list(function(fpath) {
          fpath = util.changeext(fpath, '');
          if (__indexOf.call(filelist, fpath) < 0) {
            info(fpath, 'added');
            return reset();
          }
        });
      });
    };

    Source.prototype.unwatch = function() {
      if (this.watcher) {
        this.watcher.close();
        require('./index').watchers.decr();
        return delete this.watcher;
      }
    };

    return Source;

  })();

  exports.Source = Source;

}).call(this);

==> brewer-0.3.12.tgz: package/lib/source.js <==
(function() {
  var Source, debug, info, util, _, _ref,
    __hasProp = {}.hasOwnProperty,
    __slice = [].slice,
    __indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };

  util = require('./util');

  _ref = require('./command'), debug = _ref.debug, info = _ref.info;

  _ = require('underscore');

  Source = (function() {

    Source.types = function() {
      var type, _results;
      _results = [];
      for (type in this) {
        if (!__hasProp.call(this, type)) continue;
        if (type !== 'types' && type !== 'extend' && type !== 'create') {
          _results.push(type);
        }
      }
      return _results;
    };

    Source.extend = function() {
      var alias, sources, src, _i, _len, _results;
      sources = 1 <= arguments.length ? __slice.call(arguments, 0) : [];
      _results = [];
      for (_i = 0, _len = sources.length; _i < _len; _i++) {
        src = sources[_i];
        this[src.type] = src;
        _results.push((function() {
          var _j, _len1, _ref1, _ref2, _results1;
          _ref2 = (_ref1 = src.aliases) != null ? _ref1 : [];
          _results1 = [];
          for (_j = 0, _len1 = _ref2.length; _j < _len1; _j++) {
            alias = _ref2[_j];
            _results1.push(this[alias] = src);
          }
          return _results1;
        }).call(this));
      }
      return _results;
    };

    Source.create = function(options, pkg) {
      var typ;
      if ((typ = this[options.type]) == null) {
        throw "Source type " + options.type + " not known";
      }
      return new typ(options, pkg);
    };

    function Source(options, _package) {
      var join, _ref1;
      this.options = options;
      this["package"] = _package;
      join = require('path').join;
      (require('underscore')).defaults(this.options, {
        watch: true
      });
      _ref1 = this.options, this.path = _ref1.path, this.requirements = _ref1.requirements, this.output = _ref1.output, this.prefix = _ref1.prefix;
      this.output || (this.output = join(".cache", this.path));
      this.shouldWatch = this.options.watch;
      util.makedirs(this.path);
    }

    Source.prototype.requiredModules = function() {
      return [];
    };

    Source.prototype.createFile = function(fpath) {
      var ctor, file, fullpath, imports, join, _ref1, _ref2;
      join = require('path').join;
      ctor = this.constructor;
      fullpath = join(this.path, fpath);
      fpath = util.changeext(fpath, '');
      if (this.prefix != null) {
        fpath = join(this.prefix, fpath);
      }
      file = this["package"].file(fpath, ctor.type, fullpath, this);
      file.register();
      if (this.requirements != null) {
        imports = (_ref1 = this.requirements[file.relpath]) != null ? _ref1 : [];
        imports = imports.concat((_ref2 = this.requirements.all) != null ? _ref2 : []);
        file.setImportedPaths(imports);
      }
      return file;
    };

    Source.prototype.test = function(path) {
      var ext;
      ext = this.constructor.ext;
      if (_.isArray(ext)) {
        return _.any(ext, function(_ext) {
          return util.hasext(path, _ext);
        });
      } else {
        return util.hasext(path, ext);
      }
    };

    Source.prototype.list = function(cb, end) {
      var filelist, join, rpath, walk, walker,
        _this = this;
      walk = require('walk');
      join = require('path').join;
      filelist = [];
      walker = walk.walk((rpath = join(this.path, '')), {
        followLinks: true
      });
      walker.on('file', function(root, stat, next) {
        var fpath;
        fpath = join(root.slice(rpath.length + 1), stat.name);
        if (_this.test(fpath)) {
          cb(fpath);
        }
        return next();
      });
      if (end != null) {
        return walker.on('end', end);
      }
    };

    Source.prototype.files = function(cb, list) {
      var each,
        _this = this;
      if (this.filelist != null) {
        if (cb != null) {
          (require('underscore')).each(this.filelist, cb);
        }
        if (list != null) {
          return list(this.filelist);
        }
      } else {
        this.filelist = [];
        each = function(fpath) {
          var file;
          file = _this.createFile(fpath);
          if (cb != null) {
            cb(file);
          }
          return _this.filelist.push(file);
        };
        return this.list(each, function() {
          if (list != null) {
            return list(_this.filelist);
          }
        });
      }
    };

    Source.prototype.watch = function(reset) {
      var filelist,
        _this = this;
      if (!this.shouldWatch) {
        return;
      }
      filelist = null;
      require('./index').watchers.incr();
      return this.watcher = (require('fs')).watch(this.path, function(event) {
        var f;
        if (_this.filelist == null) {
          return;
        }
        if (filelist == null) {
          filelist = (function() {
            var _i, _len, _ref1, _results;
            _ref1 = this.filelist;
            _results = [];
            for (_i = 0, _len = _ref1.length; _i < _len; _i++) {
              f = _ref1[_i];
              _results.push(f.relpath);
            }
            return _results;
          }).call(_this);
        }
        return _this.list(function(fpath) {
          fpath = util.changeext(fpath, '');
          if (__indexOf.call(filelist, fpath) < 0) {
            info(fpath, 'added');
            return reset();
          }
        });
      });
    };

    Source.prototype.unwatch = function() {
      if (this.watcher) {
        this.watcher.close();
        require('./index').watchers.decr();
        return delete this.watcher;
      }
    };

    return Source;

  })();

  exports.Source = Source;

}).call(this);
